==> hgfocus_1.8.4.tar.gz: hgfocus/man/hgfocusGO2PROBE.Rd <==
\name{hgfocusGO2PROBE}
\alias{hgfocusGO2PROBE}
\title{Map Between Gene Ontology (GO) and Manufacturer Identifiers}
\description{
   hgfocusGO2PROBE is an R environment that provides mappings between
   GO ids and manufacturer ids.
}
\details{
  Each GO term maps to a named vector of manufacturer ids. The name
  associated with each manufacturer id corresponds to the evidence code
  for that GO id. The evidence code indicates what kind of evidence
  supports the association between the GO and Entrez Gene ids. Evidence
  codes currently in use include:
  
  IMP - inferred from mutant phenotype
  
  IGI - inferred from genetic interaction

  IPI - inferred from physical interaction  

  ISS - inferred from sequence similarity  

  IDA - inferred from direct assay  

  IEP - inferred from expression pattern  

  IEA - inferred from electronic annotation  

  TAS - traceable author statement  

  NAS - non-traceable author statement  

  ND - no biological data available  

  IC - inferred by curator
  
  A GO id may be mapped to the same probe id more than once but
  the evidence code can be different. Mappings between Gene Ontology ids
  an Gene Ontology terms and other information are available in a
  separate data package named GO. 
  
  Mappings were based on data provided by:

  LocusLink Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue May 17 21:19:13 2005.

  Package built Tue May 17 21:28:34 2005
}
\references{
\url{ftp://ftp.ncbi.nlm.nih.gov/gene/DATA/}
}
\examples{
    # Convert to a list
    xx <- as.list(hgfocusGO2PROBE)
    if(length(xx) > 0){
        # Gets the probe ids for the top 2nd and 3nd GO ids
        goids <- xx[2:3]
        # Gets the probe ids for the first element of goids
        goids[[1]]
        # Evidence code for the mappings
        names(goids[[1]])
    }
}
\keyword{datasets}

==> hgfocus_1.10.0.tar.gz: hgfocus/man/hgfocusGO2PROBE.Rd <==
\name{hgfocusGO2PROBE}
\alias{hgfocusGO2PROBE}
\title{Map Between Gene Ontology (GO) and Manufacturer Identifiers}
\description{
   hgfocusGO2PROBE is an R environment that provides mappings between
   GO ids and manufacturer ids.
}
\details{
  Each GO term maps to a named vector of manufacturer ids. The name
  associated with each manufacturer id corresponds to the evidence code
  for that GO id. The evidence code indicates what kind of evidence
  supports the association between the GO and Entrez Gene ids. Evidence
  codes currently in use include:
  
  IMP - inferred from mutant phenotype
  
  IGI - inferred from genetic interaction

  IPI - inferred from physical interaction  

  ISS - inferred from sequence similarity  

  IDA - inferred from direct assay  

  IEP - inferred from expression pattern  

  IEA - inferred from electronic annotation  

  TAS - traceable author statement  

  NAS - non-traceable author statement  

  ND - no biological data available  

  IC - inferred by curator
  
  A GO id may be mapped to the same probe id more than once but
  the evidence code can be different. Mappings between Gene Ontology ids
  an Gene Ontology terms and other information are available in a
  separate data package named GO. 
  
  Mappings were based on data provided by:

  LocusLink Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue Oct  4 19:09:06 2005.

  Package built Tue Oct  4 19:23:30 2005
}
\references{
\url{ftp://ftp.ncbi.nlm.nih.gov/gene/DATA/}
}
\examples{
    # Convert to a list
    xx <- as.list(hgfocusGO2PROBE)
    if(length(xx) > 0){
        # Gets the probe ids for the top 2nd and 3nd GO ids
        goids <- xx[2:3]
        # Gets the probe ids for the first element of goids
        goids[[1]]
        # Evidence code for the mappings
        names(goids[[1]])
    }
}
\keyword{datasets}
